@@ -18,6 +18,8 @@ class OptionClass:
 	instrument="RockDrum"
 	progression="reincarnatie"
 	verbose=True
+	midifile="default.mid"
+	meter = (4,4)
 	pass
 
 class ImproviserMainWindow(QtGui.QMainWindow):
@@ -29,6 +31,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.ui.setupUi(self)
 		self.fill_combos()
 		self.connect_widgets()
+		self.set_defaults()
 
 	def fill_combos(self):
 		for x in Options.get_available_instruments():
@@ -47,17 +50,23 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 	def connect_widgets(self):
 		self.connect(self.ui.startbutton, QtCore.SIGNAL("clicked()"), self.start_simulation)
 
+	def set_defaults(self):
+		self.ui.resolution.setCurrentIndex(3)
+		self.ui.key.setCurrentIndex(6)
+
 	def start_simulation(self):
 		o = OptionClass()
 		o.SF2 = str(self.ui.soundfont.text())
-		o.resolution = self.ui.resolution.currentText()
-		o.key = self.ui.key.currentText()
-		o.bpm = self.ui.bpm.value()
-		o.duration = self.ui.duration.value()
-		o.loop = self.ui.loop.value()
-		o.wild = self.ui.wildness.value()
-		o.swing = self.ui.swing.checkState() 
-		Options.get_sequencer(o).play()
+		o.resolution = int(str(self.ui.resolution.currentText()))
+		o.key = str(self.ui.key.currentText())
+		o.bpm = int(self.ui.bpm.value())
+		o.duration = int(self.ui.duration.value())
+		o.loop = int(self.ui.loop.value())
+		o.wild = float(self.ui.wildness.value())
+		o.swing = self.ui.swing.checkState()
+		seq = Options.get_sequencer(o)
+		seq.play()
+
 
 app = QtGui.QApplication(argv)
 i = ImproviserMainWindow()
